#include "cball.h"


CBall::CBall()
{
	// Set to Identity
	World = Matrix4x4::IDENTITY;
	
	// Some default position
	Pos.x = 0.0f;
	Pos.y = 0.0f;
	Pos.z = 0.0f;
	Pos.w = 1.0f;
	
	// Texture parameters
	w = 64;
	h = 64;
	Halfw = (float)(w/2);
	Halfh = (float)(h/2);
	
	// Untransformed Sprite positions
	// Top Left
	TL.x = -Halfw;
	TL.y = -Halfh;
	TL.z = 0.0f;
	TL.w = 1.0f;
	// Bottom Left
	BL.x = -Halfw;
	BL.y =  Halfh;
	BL.z = 0.0f;
	BL.w = 1.0f;
	// Top Right
	TR.x =  Halfw;
	TR.y = -Halfh;
	TR.z = 0.0f;
	TR.w = 1.0f;
	// Bottom Right
	BR.x = Halfw;
	BR.y = Halfh;
	BR.z = 0.0f;
	BR.w = 1.0f;
	
	// Initial UV Texture offsets
	u = 0;
	v = 0;
	
	// Colour
	r = 0x80;
	g = 0x80;
	b = 0x80;
	a = 0x80;
	
	// Animation parameters
	FCountMax = 5;	
	FCount = 0;
	NFrames = 4;
	
	// Default Rotation parameters
	Rot = 0.0f;
	RotationSpeed = 0.1f;
	
	// Set to wall collision
	LastCollision = -1;
}

CBall::~CBall()
{
	//nothing
}

// Some somple animation
void CBall::Animate(void)
{
	if((FCount++)%FCountMax == 0)
		{
			v += h;
			if(v > (NFrames - 1) * h)v = 0;
		}
}

// Simple rotation
void CBall::Rotate(void)
{
	Rot += RotationSpeed;
	if(Rot > TWOPI)Rot -= TWOPI;
}

// Move the ball
void CBall::Move(void)
{
	Pos.x += Velocity.x;
	Pos.y += Velocity.y;
}

// Check for wall collisions
void CBall::WallCollision(void)
{
	// To right of screem
	if(Pos.x >= ScreenW - Halfw)
	{
		Velocity.x *= -1.0f;
		Pos.x = (ScreenW - Halfw ) - 0.01f;
		LastCollision = -1;
	}

	// To left of sceen
	if(Pos.x <= -ScreenW + Halfw)
	{
		Velocity.x *= -1.0f;
		Pos.x = (-ScreenW + Halfw) + 0.01f;
		LastCollision = -1;
	}

	// To Bottom of screen
	if(Pos.y >= ScreenH - Halfh)
	{
		Velocity.y *= -1.0f;
		Pos.y = (ScreenH - Halfh ) - 0.01f;
		LastCollision = -1;
	}

	//to top of screen
	if(Pos.y <= -ScreenH + Halfh)
	{
		Velocity.y *= -1.0f;
		Pos.y = (-ScreenH + Halfh) - 0.01f;
		LastCollision = -1;
	}
}